// pages/login/login.js
import WxValidate from '../../utils/wxValidate'
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '编排信息管理', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        form: {},
        // 比赛id
        id: '',
        // 比赛信息
        matchInfo: {},
        // 参赛团队
        matchteamList: [],
        // 红方数据
        redInfo: {},
        // 蓝方数据
        blueInfo: {},
    },
    //验证必填项
    initValidate() {
        const rules = { red_id: { required: true }, blue_id: { required: true }, date: { required: true }, time: { required: true }, }
        // 验证字段的提示信息，若不传则调用默认的信息
        const messages = { red_id: { required: '选择红方' }, blue_id: { required: '选择蓝方' }, date: { required: '选择日期' }, time: { required: '选择时间' } };
        this.WxValidate = new WxValidate(rules, messages)
    },
    back: function () {
        wx.navigateBack({ url: '/pages/lays/index' })
    },
    // 选择红方
    redChange: function (e) {
        const that = this;
        let index = e.detail.value;
        let data = that.data.matchteamList[index];
        if (data) {
            that.setData({ 'form.red_id': data._id, 'form.red_name': data.team_name })
            that.setData({ redInfo: data })
        }
    },
    // 选择蓝方
    blueChange: function (e) {
        const that = this;
        let index = e.detail.value;
        let data = that.data.matchteamList[index];
        if (data) {
            that.setData({ 'form.blue_id': data._id, 'form.blue_name': data.team_name })
            that.setData({ blueInfo: data })
        }
    },
    // 日期选择
    dateChange: function (e) {
        const that = this;
        that.setData({ 'form.date': e.detail.value });
        that.setData({ 'form.match_time': that.data.form.date + ' ' + that.data.form.time })
    },
    // 时间选择
    timeChange: function (e) {
        const that = this;
        that.setData({ 'form.time': e.detail.value });
        that.setData({ 'form.match_time': that.data.form.date + ' ' + that.data.form.time })
    },
    // 保存信息
    onSubmit: async function (e) {
        const that = this;
        let red = that.data.redInfo;
        let blue = that.data.blueInfo;
        let parmas = e.detail.value;
        parmas.red_name = red.team_name;
        parmas.red_logo = red.logo;
        parmas.red_members = red.members;
        parmas.blue_name = blue.team_name;
        parmas.blue_logo = blue.logo;
        parmas.blue_members = blue.members;
        if (!this.WxValidate.checkForm(parmas)) {
            const error = this.WxValidate.errorList[0];
            wx.showToast({ title: `${error.msg}`, icon: 'error', duration: 2000 })
            return false
        } else {
            const arr = await app.$post(`/courtAdmin/api/schedule`, parmas);
            if (arr.errcode === 0) {
                wx.showToast({ title: '保存成功', icon: 'success', duration: 2000 })
                that.back();
            } else {
                wx.showToast({ title: arr.errmsg, icon: 'error', duration: 2000 })

            }
        }
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        const that = this;
        that.setData({ id: options.id})
        //验证规则函数
        this.initValidate();
        // 计算高度
        this.searchHeight();
        // 监听用户是否登录
        this.watchLogin();

    },
    // 验证用户登录
    watchLogin: async function () {
        const that = this;
        let id = that.data.id;
        wx.getStorage({
            key: 'token',
            success: async res => {
                // 查询比赛信息
                const arr = await app.$post(`/courtAdmin/api/match/${id}`);
                if (arr.errcode === 0) {
                    that.setData({ matchInfo: arr.data });
                    // 赋值form比赛信息
                    that.setData({ 'form.match_id': arr.data._id, 'form.match_name': arr.data.name })
                }
                // 参赛团队
                const aee = await app.$get(`/courtAdmin/api/matchteam`, { match_id: id, status: 1 });
                if (aee.errcode === 0) that.setData({ matchteamList: aee.data })
            },
            fail: res => {
                return wx.redirectTo({ url: '/pages/login/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})